@@ -37,32 +37,15 @@ plot_loadings <- function(rotated_modelfit,
                           violin = TRUE,
                           conf_level = 0.95,
                           threshold=NULL) {
-  v <- reshape2::melt(rotated_modelfit$Z_rot,
-    varnames = c("iter", "name", "trend")
-  )
-  v$trend <- paste0("Trend ", v$trend)
-  v$trend <- as.factor(v$trend)
-  if (!is.null(names)) v$name <- names[v$name]
-  v$name <- as.factor(v$name)
 
-  v <- dplyr::group_by(v, .data$name, .data$trend)
-  v <- dplyr::mutate(v,
-    q_lower = sum(.data$value < 0) / length(.data$value),
-    q_upper = 1 - .data$q_lower,
-    prob_diff0 = max(.data$q_lower, .data$q_upper)
-  )
-  v <- dplyr::ungroup(v)
-
-  vsum <- dplyr::group_by(v, .data$name, .data$trend)
-  vsum <- dplyr::summarize(vsum,
-    lower = quantile(.data$value, probs = (1 - conf_level) / 2),
-    upper = quantile(.data$value, probs = 1 - (1 - conf_level) / 2),
-    median = median(.data$value),
-    q_lower = sum(.data$value < 0) / length(.data$value),
-    q_upper = 1 - .data$q_lower,
-    prob_diff0 = max(.data$q_lower, .data$q_upper)
-  )
-  df <- dplyr::ungroup(vsum)
+  v <- dfa_loadings(rotated_modelfit,
+                    summary = FALSE,
+                    names = names,
+                    conf_level = conf_level)
+  df <- dfa_loadings(rotated_modelfit,
+                     summary = TRUE,
+                     names = names,
+                     conf_level = conf_level)
 
   # filter values below threshold
   if (!is.null(threshold)) {
@@ -85,7 +68,7 @@ plot_loadings <- function(rotated_modelfit,
 
   if (violin) {
     p1 <- ggplot(v, aes_string(
-      x = "name", y = "value", fill = "trend",
+      x = "name", y = "loading", fill = "trend",
       alpha = "prob_diff0"
     )) +
       geom_violin(color = NA) +
