@@ -7,25 +7,23 @@
 #'   model. E.g. output from [invert_chains()].
 #' @export
 #' @examples
+#' \dontrun{
 #' set.seed(42)
 #' s <- sim_dfa(num_trends = 1, num_years = 20, num_ts = 3)
 #' # only 1 chain and 1000 iterations used so example runs quickly:
-#' m <- fit_dfa(y = s$y_sim, iter = 50, chains = 1)
+#' m <- fit_dfa(y = s$y_sim, iter = 2000, chains = 3, num_trends=1)
 #' pred <- predicted(m)
-#'
+#' }
 predicted <- function(fitted_model) {
   Z <- rstan::extract(fitted_model$model, "Z", permuted=FALSE)
   x <- rstan::extract(fitted_model$model, "x", permuted=FALSE)
+  Zperm <- rstan::extract(fitted_model$model, "Z", permuted=TRUE)
+  xperm <- rstan::extract(fitted_model$model, "x", permuted=TRUE)
 
+  n_ts <- dim(Zperm$Z)[2]
+  n_y <- dim(xperm$x)[3]
   n_chains <- dim(Z)[2]
-  if(fitted_model$shape == "wide") {
-    n_ts <- dim(fitted_model$data)[1]
-    n_y <- dim(fitted_model$data)[2]
-  } else {
-    n_ts = max(fitted_model$data[,"ts"])
-    n_y = max(fitted_model$data[,"time"])
-  }
-  n_trends <- dim(Z)[3]/n_ts
+  n_trends <- dim(xperm$x)[2]
   n_mcmc <- dim(x)[1]
 
   pred <- array(0, c(n_mcmc, n_chains, n_y, n_ts))
